@@ -7,10 +7,7 @@ Usage::
     import boto3
     from mypy_boto3_codepipeline import CodePipelineClient
 
-    session = boto3.Session()
-
     client: CodePipelineClient = boto3.client("codepipeline")
-    session_client: CodePipelineClient = session.client("codepipeline")
     ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
