@@ -7,7 +7,7 @@ Usage::
     import boto3
 
     from mypy_boto3_codepipeline import CodePipelineClient
-    from mypy_boto3_codepipeline import (
+    from mypy_boto3_codepipeline.paginator import (
         ListActionExecutionsPaginator,
         ListActionTypesPaginator,
         ListPipelineExecutionsPaginator,
